==> 0.1.29.tar.gz: lib/network_resources/provider/client_web.dart <==
import 'dart:convert';

import 'package:dio/browser_imp.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:logger/logger.dart';
import 'package:oowoo_core/theme/theme.dart';

const String METHOD_GET = "GET";
const String METHOD_POST = "POST";
const String METHOD_PUT = "PUT";
const String METHOD_DELETE = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClientsWeb extends DioForBrowser {
  static var _logger = Logger();
  static AppClientsWeb? _instance;
  static bool _enableErrorHandler = true;

  factory AppClientsWeb(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;
    if (requiredToken && (token == null || token.isEmpty)) {
      _logger.w('Request RequiredToken but your token is null!');
    }
    _instance ??=
        AppClientsWeb._(baseUrl: baseUrl ?? oowoobaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? oowoobaseUrl;
    (_instance!.transformer as DefaultTransformer).jsonDecodeCallback =
        parseJson;
    if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization':
            isAuthorizationCustom ? token : ('Bearer ' + (token ?? ''))
      });
    } else {
      _instance!.options.headers.remove(r'Authorization');
    }
    _logger.d("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClientsWeb._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? oowoobaseUrl;
  }

  _requestInterceptor(
      RequestOptions options, RequestInterceptorHandler handler) async {
    switch (options.method) {
      case METHOD_GET:
        _logger.d(
            "${options.method}: ${options.uri}\nParams: ${options.queryParameters}");
        break;
      case METHOD_POST:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}\nFiles: ${options.data.files}");
        }
        break;
      case METHOD_PUT:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}");
        }
        break;
      case METHOD_DELETE:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}");
        }
        break;
      default:
        break;
    }
    options.connectTimeout = 30000;
    options.receiveTimeout = 30000;
    handler.next(options);
  }

  _responseInterceptor(Response response, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${response.requestOptions.uri}: ${response.statusCode}\nData: ${response.data}");
    handler.next(response);
  }

  _errorInterceptor(DioError dioError, ErrorInterceptorHandler handler) {
    _logger.e(
        "${dioError.requestOptions.uri}\n${dioError.type} - Error ${dioError.message}\nData: ${dioError.response?.data}");
    // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    handler.next(dioError);
  }
}

==> 0.1.47.tar.gz: lib/network_resources/provider/client_web.dart <==
import 'dart:convert';

import 'package:dio/browser_imp.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:get/get.dart' as getx;
import 'package:logger/logger.dart';
import 'package:oowoo_core/oowoo_core.dart';

const String METHOD_GET = "GET";
const String METHOD_POST = "POST";
const String METHOD_PUT = "PUT";
const String METHOD_DELETE = "DELETE";

_parseAndDecode(String response) {
  return jsonDecode(response);
}

parseJson(String text) {
  return compute(_parseAndDecode, text);
}

class AppClientsWeb extends DioForBrowser {
  static var _logger = Logger();
  static AppClientsWeb? _instance;
  static bool _enableErrorHandler = true;

  factory AppClientsWeb(
      {required bool requiredToken,
      bool isAuthorizationCustom = false,
      String? token,
      String? baseUrl,
      bool enableErrorHandler = true,
      BaseOptions? options}) {
    _enableErrorHandler = enableErrorHandler;
    if (requiredToken && (token == null || token.isEmpty)) {
      _logger.w('Request RequiredToken but your token is null!');
    }
    _instance ??=
        AppClientsWeb._(baseUrl: baseUrl ?? oowoobaseUrl, options: options);
    if (options != null) _instance!.options = options;
    _instance!.options.baseUrl = baseUrl ?? oowoobaseUrl;
    (_instance!.transformer as DefaultTransformer).jsonDecodeCallback =
        parseJson;
    if (requiredToken) {
      _instance!.options.headers.addAll({
        r'Authorization':
            isAuthorizationCustom ? token : ('Bearer ' + (token ?? ''))
      });
    } else {
      _instance!.options.headers.remove(r'Authorization');
    }
    _logger.d("Header: ${_instance!.options.headers}");
    _instance!.options.headers.addAll({
      "Access-Control-Allow-Origin": "*",
      "Access-Control-Allow-Credentials": true,
      "Access-Control-Allow-Headers":
          "Origin,Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token,locale",
      "Access-Control-Allow-Methods": "POST, OPTIONS"
    });
    return _instance!;
  }

  AppClientsWeb._({String? baseUrl, BaseOptions? options}) : super(options) {
    interceptors.add(InterceptorsWrapper(
      onRequest: _requestInterceptor,
      onResponse: _responseInterceptor,
      onError: _errorInterceptor,
    ));
    this.options.baseUrl = baseUrl ?? oowoobaseUrl;
  }

  _requestInterceptor(
      RequestOptions options, RequestInterceptorHandler handler) async {
    switch (options.method) {
      case METHOD_GET:
        _logger.d(
            "${options.method}: ${options.uri}\nParams: ${options.queryParameters}");
        break;
      case METHOD_POST:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}\nFiles: ${options.data.files}");
        }
        break;
      case METHOD_PUT:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}");
        }
        break;
      case METHOD_DELETE:
        if (options.data is Map) {
          _logger
              .d("${options.method}: ${options.uri}\nParams: ${options.data}");
        } else if (options.data is FormData) {
          _logger.d(
              "${options.method}: ${options.uri}\nParams: ${options.data.fields}");
        }
        break;
      default:
        break;
    }
    options.connectTimeout = 30000;
    options.receiveTimeout = 30000;
    handler.next(options);
  }

  _responseInterceptor(Response response, ResponseInterceptorHandler handler) {
    _logger.i(
        "Response ${response.requestOptions.uri}: ${response.statusCode}\nData: ${response.data}");
    handler.next(response);
  }

  _errorInterceptor(DioError dioError, ErrorInterceptorHandler handler) {
    _logger.e(
        "${dioError.requestOptions.uri}\n${dioError.type} - Error ${dioError.message}\nData: ${dioError.response?.data}");
    if (OOWOOConfig.of(getx.Get.context!).errorInterceptor != null) {
      OOWOOConfig.of(getx.Get.context!).errorInterceptor!(dioError);
    } // if (_enableErrorHandler) ErrorHandling().onError(dioError);
    handler.next(dioError);
  }
}
